@@ -19,7 +19,7 @@ class OwncloudControl:
     def finish(self, login, password, host, protocol):
         owncloud_url = 'http://{}:{}/{}'.format(host, self.config.port_http, self.config.url)
         setup.finish(owncloud_url, login, password)
-        protocol = protocol.to_lower()
+        protocol = protocol.lower()
         if protocol == 'https':
             self.access.https_on()
         elif protocol != 'http':
